Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(105)

Unified Diff: remoting/host/plugin/host_script_object.h

Issue 10537182: The user's consent to crash dumps reporting can now be set via the UI (Windows only). The checkbox … (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebased Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/plugin/daemon_controller_win.cc ('k') | remoting/host/plugin/host_script_object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/plugin/host_script_object.h
diff --git a/remoting/host/plugin/host_script_object.h b/remoting/host/plugin/host_script_object.h
index d121266f8d9be66d2971900696e33811fc53e338..9e7110e0d0ddaeb55b62c1b8303c2ce3f5e01735 100644
--- a/remoting/host/plugin/host_script_object.h
+++ b/remoting/host/plugin/host_script_object.h
@@ -153,13 +153,20 @@ class HostNPScriptObject : public HostStatusObserver {
uint32_t arg_count,
NPVariant* result);
- // Loads daemon config version. The first argument specifies the
- // callback to be called with the config is loaded. The version is
+ // Retrieves daemon config version. The first argument specifies the
+ // callback to be called with the obtained version. The version is
// returned as a dotted version string, described in daemon_controller.h.
bool GetDaemonVersion(const NPVariant* args,
uint32_t arg_count,
NPVariant* result);
+ // Retrieves the user's consent to report crash dumps. The first argument
+ // specifies the callback to be called with the recorder consent. Possible
+ // consent codes are defined in remoting/host/breakpad.h.
+ bool GetUsageStatsConsent(const NPVariant* args,
+ uint32_t arg_count,
+ NPVariant* result);
+
// Start the daemon process with the specified config. Args are:
// string config
// function(number) done_callback
@@ -227,8 +234,8 @@ class HostNPScriptObject : public HostStatusObserver {
const std::string& public_key);
// Callback handler for SetConfigAndStart(), Stop() and SetPin() in
// DaemonController.
void InvokeAsyncResultCallback(const ScopedRefNPObject& callback,
DaemonController::AsyncResult result);
@@ -240,6 +247,12 @@ class HostNPScriptObject : public HostStatusObserver {
void InvokeGetDaemonVersionCallback(const ScopedRefNPObject& callback,
const std::string& version);
+ // Callback handler for DaemonController::GetUsageStatsConsent().
+ void InvokeGetUsageStatsConsentCallback(const ScopedRefNPObject& callback,
+ bool supported,
+ bool allowed,
+ bool set_by_policy);
+
//////////////////////////////////////////////////////////
// Basic helper methods used for both It2Me and Me2me.
« no previous file with comments | « remoting/host/plugin/daemon_controller_win.cc ('k') | remoting/host/plugin/host_script_object.cc » ('j') | no next file with comments »
@@ -227,8 +234,8 @@ class HostNPScriptObject : public HostStatusObserver {
const std::string& public_key);
- // Callback handler for SetConfigAndStart(), Stop() and SetPin() in
- // DaemonController.
+ // Callback handler for SetConfigAndStart(), Stop(), SetPin() and
+ // SetUsageStatsConsent() in DaemonController.
void InvokeAsyncResultCallback(const ScopedRefNPObject& callback,
DaemonController::AsyncResult result);

Powered by Google App Engine
This is Rietveld 408576698